@@ -177,9 +177,9 @@ settings = {
     "cookie_secret": str(uuid.uuid4()),
     "google_oauth" : {
         "key": os.environ.get("OAUTH_CLIENT_ID"),
-        "secret": os.environ.get("OAUTH_SECRET"),
-        "login_url": "/login",
-    }
+        "secret": os.environ.get("OAUTH_SECRET")
+    },
+    "login_url": "/login",
 }
 application = tornado.web.Application([
         (r"/", Userform),
